Function String_Init
Source pub unsafe fn String_Init(
buffer: *mut c_char,
length: c_int,
capacity: c_int,
) -> cc_string
Constructs a string from the given arguments.
Safety
The buffer needs to live longer than the cc_string.
Panics
Panics if length or capacity does not fit in cc_uint16.